"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SolanaAddress = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const web3_js_1 = require("@solana/web3.js");
class SolanaAddress {
    static byteSize = 32;
    address;
    constructor(address) {
        if (address instanceof connect_sdk_1.UniversalAddress)
            this.address = new web3_js_1.PublicKey(address.toUint8Array());
        if (typeof address === 'string' && (0, connect_sdk_1.isHexByteString)(address))
            this.address = new web3_js_1.PublicKey((0, connect_sdk_1.hexByteStringToUint8Array)(address));
        else
            this.address = new web3_js_1.PublicKey(address);
    }
    unwrap() {
        return this.address;
    }
    toString() {
        return this.address.toBase58();
    }
    toUint8Array() {
        return this.address.toBytes();
    }
    toNative() {
        return this;
    }
    toUniversalAddress() {
        return new connect_sdk_1.UniversalAddress(this.address.toBytes());
    }
    equals(other) {
        return this.toUniversalAddress().equals(other);
    }
}
exports.SolanaAddress = SolanaAddress;
(0, connect_sdk_1.registerNative)('Solana', SolanaAddress);
//# sourceMappingURL=address.js.map