import { isHexByteString, hexByteStringToUint8Array, registerNative, UniversalAddress, } from '@wormhole-foundation/connect-sdk';
import { PublicKey } from '@solana/web3.js';
export class SolanaAddress {
    static byteSize = 32;
    address;
    constructor(address) {
        if (address instanceof UniversalAddress)
            this.address = new PublicKey(address.toUint8Array());
        if (typeof address === 'string' && isHexByteString(address))
            this.address = new PublicKey(hexByteStringToUint8Array(address));
        else
            this.address = new PublicKey(address);
    }
    unwrap() {
        return this.address;
    }
    toString() {
        return this.address.toBase58();
    }
    toUint8Array() {
        return this.address.toBytes();
    }
    toNative() {
        return this;
    }
    toUniversalAddress() {
        return new UniversalAddress(this.address.toBytes());
    }
    equals(other) {
        return this.toUniversalAddress().equals(other);
    }
}
registerNative('Solana', SolanaAddress);
//# sourceMappingURL=address.js.map