import { Connection } from '@solana/web3.js';
import { Program } from '@project-serum/anchor';
import { Contracts, ChainsConfig, ChainName } from '@wormhole-foundation/connect-sdk';
import { TokenBridge } from './utils/types/tokenBridge';
import { Wormhole as WormholeCore } from './utils/types/wormhole';
import { NftBridge } from './utils/types/nftBridge';
/**
 * @category Solana
 */
export declare class SolanaContracts {
    protected _contracts: Map<ChainName, Contracts>;
    constructor(conf: ChainsConfig);
    getContracts(chain: ChainName): Contracts | undefined;
    mustGetContracts(chain: ChainName): Contracts;
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, undefined if not found
     */
    getCore(chain: ChainName, connection: Connection): Program<WormholeCore> | undefined;
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, errors if not found
     */
    mustGetCore(chain: ChainName, connection: Connection): Program<WormholeCore>;
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, undefined if not found
     */
    getTokenBridge(chain: ChainName, connection: Connection): Program<TokenBridge> | undefined;
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, errors if not found
     */
    mustGetTokenBridge(chain: ChainName, connection: Connection): Program<TokenBridge>;
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, undefined if not found
     */
    getNftBridge(chain: ChainName, connection: Connection): Program<NftBridge> | undefined;
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, errors if not found
     */
    mustGetNftBridge(chain: ChainName, connection: Connection): Program<NftBridge>;
}
//# sourceMappingURL=contracts.d.ts.map