import { Commitment, Connection } from '@solana/web3.js';
import { ChainName, Platform, TokenId, TokenBridge, AutomaticTokenBridge, CircleBridge, AutomaticCircleBridge, SignedTx, TxHash, WormholeMessageId, ChainsConfig, ChainContext, SolRpc, NativeAddress, WormholeCore } from '@wormhole-foundation/connect-sdk';
import { SolanaContracts } from './contracts';
/**
 * @category Solana
 */
export declare class SolanaPlatform implements Platform<'Solana'> {
    static readonly _platform: 'Solana';
    readonly platform: "Solana";
    readonly conf: ChainsConfig;
    readonly contracts: SolanaContracts;
    constructor(conf: ChainsConfig);
    getRpc(chain: ChainName, commitment?: Commitment): Connection;
    getChain(chain: ChainName): ChainContext<'Solana'>;
    getDecimals(chain: ChainName, rpc: Connection, token: TokenId | 'native'): Promise<bigint>;
    getBalance(chain: ChainName, rpc: Connection, walletAddress: string, token: TokenId | 'native'): Promise<bigint | null>;
    sendWait(rpc: Connection, stxns: SignedTx[]): Promise<TxHash[]>;
    getWormholeCore(rpc: SolRpc): Promise<WormholeCore<'Solana'>>;
    getTokenBridge(rpc: Connection): Promise<TokenBridge<'Solana'>>;
    getAutomaticTokenBridge(rpc: Connection): Promise<AutomaticTokenBridge<'Solana'>>;
    getCircleBridge(rpc: Connection): Promise<CircleBridge<'Solana'>>;
    getAutomaticCircleBridge(rpc: Connection): Promise<AutomaticCircleBridge<'Solana'>>;
    parseAddress(chain: ChainName, address: string): NativeAddress<'Solana'>;
    parseTransaction(chain: ChainName, rpc: Connection, tx: string): Promise<WormholeMessageId[]>;
}
//# sourceMappingURL=platform.d.ts.map